/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import java.math.BigInteger;
import java.util.List;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.types.Cdrom;

/**
 * Manages the CDROM devices of a virtual machine.
 * 
 * Currently virtual machines have exactly one CDROM device. No new devices can be added, and the existing one can't
 * be removed, thus there are no `add` or `remove` methods. Changing and ejecting CDROM disks is done with the
 * <<services/vm_cdrom/methods/update, update>> method of the <<services/vm_cdrom, service>> that manages the
 * CDROM device.
 */
public interface VmCdromsService extends Service {
    /**
     * Returns the list of CDROM devices of the virtual machine.
     * 
     * The order of the returned list of CD-ROM devices isn't guaranteed.
     */
    public interface ListRequest extends Request<ListRequest, ListResponse> {
        /**
         * Sets the maximum number of CDROMs to return. If not specified all the CDROMs are returned.
         */
        ListRequest max(Integer max);
        /**
         * Sets the maximum number of CDROMs to return. If not specified all the CDROMs are returned.
         */
        ListRequest max(Long max);
        /**
         * Sets the maximum number of CDROMs to return. If not specified all the CDROMs are returned.
         */
        ListRequest max(BigInteger max);
    }
    
    /**
     * Returns the list of CDROM devices of the virtual machine.
     * 
     * The order of the returned list of CD-ROM devices isn't guaranteed.
     */
    public interface ListResponse extends Response {
        /**
         * The list of CDROM devices of the virtual machine.
         */
        List<Cdrom> cdroms();
    }
    
    /**
     * Returns the list of CDROM devices of the virtual machine.
     * 
     * The order of the returned list of CD-ROM devices isn't guaranteed.
     */
    ListRequest list();
    
    /**
     * Returns a reference to the service that manages a specific CDROM device.
     */
    VmCdromService cdromService(String id);
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

