/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.services;

import java.io.IOException;
import org.ovirt.engine.sdk4.Request;
import org.ovirt.engine.sdk4.Response;
import org.ovirt.engine.sdk4.Service;
import org.ovirt.engine.sdk4.builders.VnicProfileBuilder;
import org.ovirt.engine.sdk4.types.VnicProfile;

/**
 * This service manages a vNIC profile.
 */
public interface VnicProfileService extends Service {
    /**
     * Retrieves details about a vNIC profile.
     */
    public interface GetRequest extends Request<GetRequest, GetResponse> {
    }
    
    /**
     * Retrieves details about a vNIC profile.
     */
    public interface GetResponse extends Response {
        VnicProfile profile();
    }
    
    /**
     * Retrieves details about a vNIC profile.
     */
    GetRequest get();
    
    /**
     * Removes the vNIC profile.
     */
    public interface RemoveRequest extends Request<RemoveRequest, RemoveResponse> {
        /**
         * Indicates if the remove should be performed asynchronously.
         */
        RemoveRequest async(Boolean async);
    }
    
    /**
     * Removes the vNIC profile.
     */
    public interface RemoveResponse extends Response {
    }
    
    /**
     * Removes the vNIC profile.
     */
    RemoveRequest remove();
    
    /**
     * Updates details of a vNIC profile.
     */
    public interface UpdateRequest extends Request<UpdateRequest, UpdateResponse> {
        /**
         * Indicates if the update should be performed asynchronously.
         */
        UpdateRequest async(Boolean async);
        UpdateRequest profile(VnicProfile profile);
        /**
         * The vNIC profile that is being updated.
         */
        UpdateRequest profile(VnicProfileBuilder profile);
    }
    
    /**
     * Updates details of a vNIC profile.
     */
    public interface UpdateResponse extends Response {
        /**
         * The vNIC profile that is being updated.
         */
        VnicProfile profile();
    }
    
    /**
     * Updates details of a vNIC profile.
     */
    UpdateRequest update();
    
    AssignedPermissionsService permissionsService();
    /**
     * Service locator method, returns individual service on which the URI is dispatched.
     */
    Service service(String path);
}

